aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorfriendica <info@friendica.com>2012-02-20 18:07:16 -0800
committerfriendica <info@friendica.com>2012-02-20 18:07:16 -0800
commit6edd6d8ae1e3a6b64fa11ae6a4cc79965084b0d7 (patch)
tree4e3561b4f5e457d4420a232e0a233b6688d7745a /include
parent11871195be019bb05c7c41dbb4a980fffce41697 (diff)
parent1cfff8fdd11e0e67e2bdb7ae85b9caf8106a734b (diff)
downloadvolse-hubzilla-6edd6d8ae1e3a6b64fa11ae6a4cc79965084b0d7.tar.gz
volse-hubzilla-6edd6d8ae1e3a6b64fa11ae6a4cc79965084b0d7.tar.bz2
volse-hubzilla-6edd6d8ae1e3a6b64fa11ae6a4cc79965084b0d7.zip
Merge branch 'pull'
Diffstat (limited to 'include')
-rwxr-xr-xinclude/Scrape.php2
-rwxr-xr-xinclude/acl_selectors.php2
-rwxr-xr-xinclude/api.php6
-rwxr-xr-xinclude/nav.php2
-rwxr-xr-xinclude/poller.php2
-rwxr-xr-xinclude/text.php2
6 files changed, 8 insertions, 8 deletions
diff --git a/include/Scrape.php b/include/Scrape.php
index e42d22afc..52405ae2d 100755
--- a/include/Scrape.php
+++ b/include/Scrape.php
@@ -314,7 +314,7 @@ function scrape_feed($url) {
*
* PROBE_DIASPORA has a bias towards returning Diaspora information
* while PROBE_NORMAL has a bias towards dfrn/zot - in the case where
- * an address (such as a Friendika address) supports more than one type
+ * an address (such as a Friendica address) supports more than one type
* of network.
*
*/
diff --git a/include/acl_selectors.php b/include/acl_selectors.php
index d8f530daf..6070b7db2 100755
--- a/include/acl_selectors.php
+++ b/include/acl_selectors.php
@@ -157,7 +157,7 @@ function contact_select($selname, $selclass, $preselected = false, $size = 4, $p
$o = '';
- // When used for private messages, we limit correspondence to mutual DFRN/Friendika friends and the selector
+ // When used for private messages, we limit correspondence to mutual DFRN/Friendica friends and the selector
// to one recipient. By default our selector allows multiple selects amongst all contacts.
$sql_extra = '';
diff --git a/include/nav.php b/include/nav.php
index 95dd37ba6..c8a44af80 100755
--- a/include/nav.php
+++ b/include/nav.php
@@ -148,7 +148,7 @@ function nav(&$a) {
$banner = get_config('system','banner');
if($banner === false)
- $banner .= '<a href="http://friendica.com"><img id="logo-img" src="images/friendika-32.png" alt="logo" /></a><span id="logo-text"><a href="http://friendica.com">Friendica</a></span>';
+ $banner .= '<a href="http://friendica.com"><img id="logo-img" src="images/friendica-32.png" alt="logo" /></a><span id="logo-text"><a href="http://friendica.com">Friendica</a></span>';
$tpl = get_markup_template('nav.tpl');
diff --git a/include/poller.php b/include/poller.php
index 7d42c63b5..3e10533b3 100755
--- a/include/poller.php
+++ b/include/poller.php
@@ -349,7 +349,7 @@ function poller_run($argv, $argc){
|| ($contact['network'] === NETWORK_DIASPORA)
|| ($contact['network'] === NETWORK_FEED) ) {
- // Upgrading DB fields from an older Friendika version
+ // Upgrading DB fields from an older Friendica version
// Will only do this once per notify-enabled OStatus contact
// or if relationship changes
diff --git a/include/text.php b/include/text.php
index b2c7862ce..5ef870fd7 100755
--- a/include/text.php
+++ b/include/text.php
@@ -759,7 +759,7 @@ function smilies($s, $sample = false) {
'<img src="' . $a->get_baseurl() . '/images/smiley-facepalm.gif" alt=":facepalm" />',
'<img src="' . $a->get_baseurl() . '/images/smiley-bangheaddesk.gif" alt=":headdesk" />',
'<a href="http://project.friendika.com">~friendika <img src="' . $a->get_baseurl() . '/images/friendika-16.png" alt="~friendika" /></a>',
- '<a href="http://friendica.com">~friendica <img src="' . $a->get_baseurl() . '/images/friendika-16.png" alt="~friendica" /></a>',
+ '<a href="http://friendica.com">~friendica <img src="' . $a->get_baseurl() . '/images/friendica-16.png" alt="~friendica" /></a>',
'<a href="http://diasporafoundation.org">Diaspora<img src="' . $a->get_baseurl() . '/images/diaspora.png" alt="Diaspora*" /></a>',
);
diff --git a/include/api.php b/include/api.php
index 7b8709659..04f95ebd9 100755
--- a/include/api.php
+++ b/include/api.php
@@ -179,7 +179,7 @@
'updated' => api_date(null),
'atom_updated' => datetime_convert('UTC','UTC','now',ATOM_TIME),
'language' => $user_info['language'],
- 'logo' => $a->get_baseurl()."/images/friendika-32.png",
+ 'logo' => $a->get_baseurl()."/images/friendica-32.png",
);
return $arr;
@@ -739,7 +739,7 @@
if (local_user()===false) return false;
$user_info = api_get_user($a);
// in friendika starred item are private
// return favorites only for self
logger('api_favorites: self:' . $user_info['self']);
@@ -912,7 +912,7 @@
function api_statusnet_config(&$a,$type) {
$name = $a->config['sitename'];
$server = $a->get_hostname();
- $logo = $a->get_baseurl() . '/images/friendika-64.png';
+ $logo = $a->get_baseurl() . '/images/friendica-64.png';
$email = $a->config['admin_email'];
$closed = (($a->config['register_policy'] == REGISTER_CLOSED) ? 'true' : 'false');
$private = (($a->config['system']['block_public']) ? 'true' : 'false');
@@ -739,7 +739,7 @@
if (local_user()===false) return false;
$user_info = api_get_user($a);
- // in friendika starred item are private
+ // in friendica starred item are private
// return favorites only for self
logger('api_favorites: self:' . $user_info['self']);